Struct polkadot_primitives::v0::GlobalValidationData [−][src]
pub struct GlobalValidationData<N = BlockNumber> {
pub max_code_size: u32,
pub max_head_data_size: u32,
pub block_number: N,
}Expand description
Extra data that is needed along with the other fields in a CandidateReceipt
to fully validate the candidate.
These are global parameters that apply to all parachain candidates in a block.
Fields
max_code_size: u32The maximum code size permitted, in bytes.
max_head_data_size: u32The maximum head-data size permitted, in bytes.
block_number: NThe relay-chain block number this is in the context of.