Struct polkadot_primitives::v0::LocalValidationData [−][src]
pub struct LocalValidationData<N = BlockNumber> {
pub parent_head: HeadData,
pub balance: Balance,
pub code_upgrade_allowed: Option<N>,
}Expand description
Extra data that is needed along with the other fields in a CandidateReceipt
to fully validate the candidate. These fields are parachain-specific.
Fields
parent_head: HeadDataThe parent head-data.
balance: BalanceThe balance of the parachain at the moment of validation.
code_upgrade_allowed: Option<N>Whether the parachain is allowed to upgrade its validation code.
This is Some if so, and contains the number of the minimum relay-chain
height at which the upgrade will be applied, if an upgrade is signaled
now.
A parachain should enact its side of the upgrade at the end of the first parablock executing in the context of a relay-chain block with at least this height. This may be equal to the current perceived relay-chain block height, in which case the code upgrade should be applied at the end of the signaling block.