Enum polkadot_primitives::v1::ConsensusLog [−][src]
pub enum ConsensusLog {
ParaUpgradeCode(Id, ValidationCodeHash),
ParaScheduleUpgradeCode(Id, ValidationCodeHash, BlockNumber),
ForceApprove(BlockNumber),
Revert(BlockNumber),
}Expand description
A consensus log item for polkadot validation. To be used with POLKADOT_ENGINE_ID.
Variants
ParaUpgradeCode(Id, ValidationCodeHash)A parachain or parathread upgraded its code.
Tuple Fields of ParaUpgradeCode
0: Id1: ValidationCodeHashParaScheduleUpgradeCode(Id, ValidationCodeHash, BlockNumber)A parachain or parathread scheduled a code upgrade.
Tuple Fields of ParaScheduleUpgradeCode
ForceApprove(BlockNumber)Governance requests to auto-approve every candidate included up to the given block number in the current chain, inclusive.
Tuple Fields of ForceApprove
0: BlockNumberRevert(BlockNumber)A signal to revert the block number in the same chain as the header this digest is part of and all of its descendants.
It is a no-op for a block to contain a revert digest targeting its own number or a higher number.
In practice, these are issued when on-chain logic has detected an invalid parachain block within its own chain, due to a dispute.
Tuple Fields of Revert
0: BlockNumberImplementations
Attempt to convert a reference to a generic digest item into a consensus log.