Struct polkadot_primitives::v1::CandidateCommitments [−][src]
pub struct CandidateCommitments<N = BlockNumber> {
pub upward_messages: Vec<UpwardMessage>,
pub horizontal_messages: Vec<OutboundHrmpMessage<Id>>,
pub new_validation_code: Option<ValidationCode>,
pub head_data: HeadData,
pub processed_downward_messages: u32,
pub hrmp_watermark: N,
}Expand description
Commitments made in a CandidateReceipt. Many of these are outputs of validation.
Fields
upward_messages: Vec<UpwardMessage>Messages destined to be interpreted by the Relay chain itself.
horizontal_messages: Vec<OutboundHrmpMessage<Id>>Horizontal messages sent by the parachain.
new_validation_code: Option<ValidationCode>New validation code.
head_data: HeadDataThe head-data produced as a result of execution.
processed_downward_messages: u32The number of messages processed from the DMQ.
hrmp_watermark: NThe mark which specifies the block number up to which all inbound HRMP messages are processed.
Implementations