Struct polkadot_primitives::v1::SessionInfo [−][src]
pub struct SessionInfo {
pub validators: Vec<ValidatorId>,
pub discovery_keys: Vec<AuthorityDiscoveryId>,
pub assignment_keys: Vec<AssignmentId>,
pub validator_groups: Vec<Vec<ValidatorIndex>>,
pub n_cores: u32,
pub zeroth_delay_tranche_width: u32,
pub relay_vrf_modulo_samples: u32,
pub n_delay_tranches: u32,
pub no_show_slots: u32,
pub needed_approvals: u32,
}Expand description
Information about validator sets of a session.
Fields
validators: Vec<ValidatorId>Validators in canonical ordering.
NOTE: There might be more authorities in the current session, than validators participating
in parachain consensus. See
max_validators.
SessionInfo::validators will be limited to to max_validators when set.
discovery_keys: Vec<AuthorityDiscoveryId>Validators’ authority discovery keys for the session in canonical ordering.
NOTE: The first validators.len() entries will match the corresponding validators in
validators, afterwards any remaining authorities can be found. This is any authorities not
participating in parachain consensus - see
max_validators
assignment_keys: Vec<AssignmentId>The assignment keys for validators.
NOTE: There might be more authorities in the current session, than validators participating
in parachain consensus. See
max_validators.
Therefore:
assignment_keys.len() == validators.len() && validators.len() <= discovery_keys.len()validator_groups: Vec<Vec<ValidatorIndex>>Validators in shuffled ordering - these are the validator groups as produced
by the Scheduler module for the session and are typically referred to by
GroupIndex.
n_cores: u32The number of availability cores used by the protocol during this session.
zeroth_delay_tranche_width: u32The zeroth delay tranche width.
relay_vrf_modulo_samples: u32The number of samples we do of relay_vrf_modulo.
n_delay_tranches: u32The number of delay tranches in total.
no_show_slots: u32How many slots (BABE / SASSAFRAS) must pass before an assignment is considered a no-show.
needed_approvals: u32The number of validators needed to approve a block.