Struct polkadot_primitives::v1::UncheckedSigned [−][src]
pub struct UncheckedSigned<Payload, RealPayload = Payload> { /* fields omitted */ }Expand description
Unchecked signed data, can be converted to Signed by checking the signature.
Implementations
impl<Payload: EncodeAs<RealPayload>, RealPayload: Encode> UncheckedSigned<Payload, RealPayload>
impl<Payload: EncodeAs<RealPayload>, RealPayload: Encode> UncheckedSigned<Payload, RealPayload>
pub fn new(
payload: Payload,
validator_index: ValidatorIndex,
signature: ValidatorSignature
) -> Self
pub fn new(
payload: Payload,
validator_index: ValidatorIndex,
signature: ValidatorSignature
) -> Self
Used to create a UncheckedSigned from already existing parts.
Signature is not checked here, hence UncheckedSigned.
pub fn try_into_checked<H: Encode>(
self,
context: &SigningContext<H>,
key: &ValidatorId
) -> Result<Signed<Payload, RealPayload>, Self>
pub fn try_into_checked<H: Encode>(
self,
context: &SigningContext<H>,
key: &ValidatorId
) -> Result<Signed<Payload, RealPayload>, Self>
Check signature and convert to Signed if successful.
Immutably access the payload.
Immutably access the validator index.
Immutably access the signature.
Discard signing data, get the payload
pub fn unchecked_convert_payload(&self) -> UncheckedSigned<RealPayload> where
for<'a> &'a Payload: Into<RealPayload>,
pub fn unchecked_convert_payload(&self) -> UncheckedSigned<RealPayload> where
for<'a> &'a Payload: Into<RealPayload>,
Convert Payload into RealPayload.
pub fn benchmark_sign<H: Encode>(
public: &ValidatorId,
payload: Payload,
context: &SigningContext<H>,
validator_index: ValidatorIndex
) -> Self
pub fn benchmark_sign<H: Encode>(
public: &ValidatorId,
payload: Payload,
context: &SigningContext<H>,
validator_index: ValidatorIndex
) -> Self
Sign this payload with the given context and pair.
Immutably access the signature.
Set the signature. Only should be used for creating testing mocks.