Type Definition polkadot_primitives::v1::AssignmentId [−][src]
pub type AssignmentId = Public;Expand description
The public key of a keypair used by a validator for determining assignments to approve included parachain candidates.